@@ -259,10 +259,17 @@ public:
   /// \brief Use Kokkos::Profiling in Tpetra::ProfilingRegion
   ///
   /// This is enabled by default if KOKKOS_ENABLE_PROFILING is defined.
-  /// You mau control this at run time via the <tt>TPETRA_USE_KOKKOS_PROFILING</tt>
+  /// You may control this at run time via the <tt>TPETRA_USE_KOKKOS_PROFILING</tt>
   /// environment variable.
   static bool profilingRegionUseKokkosProfiling();
 
+  /// \brief Fusing SpMV and update in residual instead of using 2 kernel launches.
+  /// Fusing kernels implies that no TPLs (CUSPARSE, ROCSPARSE, ...) will be used for the residual.
+  ///
+  /// This is enabled by default.  You may control this at run time via the
+  /// <tt>TPETRA_FUSED_RESIDUAL</tt> environment variable.
+  static bool fusedResidual();
+
   /// \brief Skip copyAndPermute if possible
   ///
   /// This is disabled by default.  You may control this at run time via the
